==> ejc-zdsstore-impl-3.0.0-20231229.072201-55-sources.jar: com/ejianc/business/zdsstore/controller/AllotOutController.java <==
package com.ejianc.business.zdsstore.controller;

import java.io.Serializable;

import com.ejianc.business.zdsstore.service.*;
import com.ejianc.business.zdsstore.vo.*;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.zdsstore.bean.AllotOutEntity;

/**
 * 调拨出库
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("allotOut")
public class AllotOutController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IOrgApi iOrgApi;

    @Autowired
    private IAllotOutService service;

    @Autowired
    StoreManageService storeManageService;

    @Autowired
    IStoreService storeService;

    @Autowired
    private ICommonBusinessService allotOut;


    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<AllotOutVO> saveOrUpdate(@RequestBody AllotOutVO saveOrUpdateVO) {
        CommonResponse<AllotOutVO> vo= service.allotOutSaveOrUpdate(saveOrUpdateVO);
    	return vo;
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<AllotOutVO> queryDetail(Long id) {
    	AllotOutEntity entity = service.selectById(id);
    	AllotOutVO vo = BeanMapper.map(entity, AllotOutVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<AllotOutVO> vos) {
        CommonResponse<String>  commonResponse =service.allotOutDelete(vos);
        return commonResponse;
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<AllotOutVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("storeName");
        fuzzyFields.add("materialNames");
        fuzzyFields.add("inProjectName");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("receiverPerson");
        fuzzyFields.add("billCode");
        fuzzyFields.add("companyName");
        fuzzyFields.add("inCompanyName");
        /** 租户隔离 */
//        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
//
//
//        //查询本下范围内日的合同
//        Long orgId = InvocationInfoProxy.getOrgId();
//        CommonResponse<List<OrgVO>> orgResp = iOrgApi.findChildrenByParentId(orgId);
//        if(!orgResp.isSuccess()) {
//            logger.error("分页查询失败，获取当前本下组织信息失败, {}", orgResp.getMsg());
//            return CommonResponse.error("查询失败，获取组织信息失败！");
//        }
//        List<Long> orgIdList = orgResp.getData().stream().map(OrgVO::getId).collect(Collectors.toList());
//        param.getParams().put("orgId", new Parameter(QueryParam.IN, orgIdList));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
        } else {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        IPage<AllotOutEntity> page = service.queryPage(param,false);
        IPage<AllotOutVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), AllotOutVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        service.excelExport(param, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refAllotOutData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<AllotOutVO>> refAllotOutData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<AllotOutEntity> page = service.queryPage(param,false);
        IPage<AllotOutVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), AllotOutVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    @RequestMapping(value = "/surplusMaterialPrice", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<StoreManageVO>> surplusMaterialPrice(@RequestBody AllotOutVO saveOrUpdateVO) {
        CommonResponse<List<StoreManageVO>> listCommonResponse = service.surplusListMaterialPrice(saveOrUpdateVO);
        return listCommonResponse ;
    }


    /**
     * 成本改造
     * 关联保存接口
     * @param
     * @return
     */
    @RequestMapping(value = "/pushCost", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<AllotOutVO> pushCost(@RequestBody AllotOutVO allotOutVO) {
        return service.pushCost(allotOutVO);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/querytestDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<AllotOutVO> querytestDetail(Long id) {
        allotOut.afterApprovalProcessor(id,0,"BT220209000000004");
        return CommonResponse.success("查询详情数据成功！");
    }
    /**
     *
     * @return
     */
    @RequestMapping(value = "/checkParams", method=RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ParamsCheckVO> checkParams(@RequestBody AllotOutVO vo) {
        ParamsCheckVO paramsCheckVO = service.checkParams(vo);
        return CommonResponse.success("参数校验成功！",paramsCheckVO );
    }
}

==> ejc-zdsstore-impl-3.0.0-20240102.032534-58-sources.jar: com/ejianc/business/zdsstore/controller/AllotOutController.java <==
package com.ejianc.business.zdsstore.controller;

import java.io.Serializable;

import com.ejianc.business.zdsstore.service.*;
import com.ejianc.business.zdsstore.vo.*;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.zdsstore.bean.AllotOutEntity;

/**
 * 调拨出库
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("allotOut")
public class AllotOutController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IOrgApi iOrgApi;

    @Autowired
    private IAllotOutService service;

    @Autowired
    StoreManageService storeManageService;

    @Autowired
    IStoreService storeService;

    @Autowired
    private ICommonBusinessService allotOut;


    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<AllotOutVO> saveOrUpdate(@RequestBody AllotOutVO saveOrUpdateVO) {
        CommonResponse<AllotOutVO> vo= service.allotOutSaveOrUpdate(saveOrUpdateVO);
    	return vo;
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<AllotOutVO> queryDetail(Long id) {
    	AllotOutEntity entity = service.selectById(id);
    	AllotOutVO vo = BeanMapper.map(entity, AllotOutVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<AllotOutVO> vos) {
        CommonResponse<String>  commonResponse =service.allotOutDelete(vos);
        return commonResponse;
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<AllotOutVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("storeName");
        fuzzyFields.add("materialNames");
        fuzzyFields.add("inProjectName");
        fuzzyFields.add("employeeName");
        fuzzyFields.add("receiverPerson");
        fuzzyFields.add("billCode");
        fuzzyFields.add("companyName");
        fuzzyFields.add("inCompanyName");
        /** 租户隔离 */
//        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
//
//
//        //查询本下范围内日的合同
//        Long orgId = InvocationInfoProxy.getOrgId();
//        CommonResponse<List<OrgVO>> orgResp = iOrgApi.findChildrenByParentId(orgId);
//        if(!orgResp.isSuccess()) {
//            logger.error("分页查询失败，获取当前本下组织信息失败, {}", orgResp.getMsg());
//            return CommonResponse.error("查询失败，获取组织信息失败！");
//        }
//        List<Long> orgIdList = orgResp.getData().stream().map(OrgVO::getId).collect(Collectors.toList());
//        param.getParams().put("orgId", new Parameter(QueryParam.IN, orgIdList));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
            param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
        } else {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentIdWithoutProjectDept(
                    InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        }
        IPage<AllotOutEntity> page = service.queryPage(param,false);
        IPage<AllotOutVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), AllotOutVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        service.excelExport(param, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refAllotOutData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<AllotOutVO>> refAllotOutData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<AllotOutEntity> page = service.queryPage(param,false);
        IPage<AllotOutVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), AllotOutVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    @RequestMapping(value = "/surplusMaterialPrice", method = RequestMethod.POST)
    @ResponseBody
    CommonResponse<List<StoreManageVO>> surplusMaterialPrice(@RequestBody AllotOutVO saveOrUpdateVO) {
        CommonResponse<List<StoreManageVO>> listCommonResponse = service.surplusListMaterialPrice(saveOrUpdateVO);
        return listCommonResponse ;
    }


//    /**
//     * 成本改造
//     * 关联保存接口
//     * @param
//     * @return
//     */
//    @RequestMapping(value = "/pushCost", method = RequestMethod.POST)
//    @ResponseBody
//    public CommonResponse<AllotOutVO> pushCost(@RequestBody AllotOutVO allotOutVO) {
//        return service.pushCost(allotOutVO);
//    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/querytestDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<AllotOutVO> querytestDetail(Long id) {
        allotOut.afterApprovalProcessor(id,0,"BT220209000000004");
        return CommonResponse.success("查询详情数据成功！");
    }
//    /**
//     *
//     * @return
//     */
//    @RequestMapping(value = "/checkParams", method=RequestMethod.POST)
//    @ResponseBody
//    public CommonResponse<ParamsCheckVO> checkParams(@RequestBody AllotOutVO vo) {
//        ParamsCheckVO paramsCheckVO = service.checkParams(vo);
//        return CommonResponse.success("参数校验成功！",paramsCheckVO );
//    }
}
